% Import sea surface temperature grids from several HDF5 layers
file = 'A2016152023000.L2_LAC_SST.nc=gd?HDF5:"A2016152023000.L2_LAC_SST.nc"';
sst  = gmt ('read', ['-Tg ' file '://geophysical_data/sst']);
qual = gmt ('read', ['-Tg ' file '://geophysical_data/qual_sst']);
lat  = gmt ('read', ['-Tg ' file '://navigation_data/latitude']);
lon  = gmt ('read', ['-Tg ' file '://navigation_data/longitude']);
% Ignore points of low quality
sst.z (qual.z > 0) = [];
lon.z (qual.z > 0) = [];
lat.z (qual.z > 0) = [];
% Perform nearest neighbor gridding
G = gmt ('nearneighbor', '-R-12/-1/33/43 -I0.01 -S0.05', [lon.z' lat.z' sst.z']);
% Create a mask that is NaN where no data exist
mask = gmt ('grdmask', '-R -I0.01 -NNaN/1/1 -S0.02', [lon.z' lat.z']);
% Apply the mask to limit the plot that follows
G.z = G.z .* mask.z;
% Select color table and make PDF illustration and display it in MATLAB
cpt_s = gmt ('grd2cpt', '-Cjet -E -M --COLOR_NAN=255', G);
cpt_t = gmt ('makecpt', '-Celevation -T0/3000');
gmt ('grdimage', '-JM15c -C -Ba -BWSne -P -K > WL_example_3.ps', G, cpt_s)
arg = ['-TdjTR+w3c+o1c+f3+l --FONT_TITLE=12 --MAP_TITLE_OFFSET=5p '];
% Clip topography to only plot over land, using shading
gmt ('pscoast', '-Di -Gc -A1000 -J -R -O -K >> WL_example_3.ps')
int = gmt ('grdgradient', '-R etopo1m.nc -A0 -Nt0.7');
gmt ('grdimage', '-R -J -O -K -C etopo1m.nc -I -t50 >> WL_example_3.ps', ...
    cpt_t, int)
gmt ('pscoast', '-Q -O -K >> WL_example_3.ps')
gmt ('pscoast', ['-Di -W0.5p -A1000 -N1/0.5p -J -R ' arg ' -O -K ' ...
    '>> WL_example_3.ps'])
gmt ('psscale', ['-R -J -C -DJBC+w14c/0.25c+o0/1c+h+ef -Baf+u" m" ' ...
    '-O -K >> WL_example_3.ps'], cpt_t)
gmt ('psscale', ['-R -J -C -DJTC+w14c/0.25c+o0/1c+h -Ba1f+u\232 ' ...
    '-O >> WL_example_3.ps'], cpt_s)
gmt ('psconvert', '-Tef -P -A -G/usr/local/bin/gs WL_example_3.ps')
open ('WL_example_3.pdf');
